%define anolis_release 1
%global pkgname Django

Name:           python-django
Version:        4.2.14
Release:        %{anolis_release}%{?dist}
Summary:        A high-level Python Web framework

License:        BSD-3-Clause
URL:            https://www.djangoproject.com/
Source:         %{pypi_source %{pkgname} %{version}}
#Source:         %{name}.rpmlintrc

BuildArch:      noarch

%global _description %{expand:
Django is a high-level Python Web framework that encourages rapid
development and a clean, pragmatic design. It focuses on automating as
much as possible and adhering to the DRY (Don't Repeat Yourself)
principle.}

%description %_description


%package -n python3-django-bash-completion
Summary:        Bash completion files for Django
BuildRequires:  bash-completion
Requires:       bash-completion

# Make sure this replaces any other Django bash-completion package
#Provides:       python3-django-bash-completion-impl
#Conflicts:      python3-django-bash-completion-impl

%description -n python3-django-bash-completion
This package contains the Bash completion files form Django high-level
Python Web framework.


%package -n python3-django-doc
Summary:        Documentation for Django
Suggests:       python3-django = %{version}-%{release}
BuildRequires:  make

# Make sure this replaces any other Django doc package
#Provides:       python3-django-doc-impl
#Conflicts:      python3-django-doc-impl

%description -n python3-django-doc
This package contains the documentation for the Django high-level
Python Web framework.


%package -n python3-django
Summary:        A high-level Python Web framework

Recommends:     (python3-django-bash-completion = %{version}-%{release} if bash-completion)

BuildRequires:  python3-devel
BuildRequires:  python3-asgiref

Provides: bundled(jquery) = 2.2.3
Provides: bundled(xregexp) = 2.0.0

# see django/contrib/admin/static/admin/js/vendor/
#Provides:       bundled(jquery) = 3.6.4
#Provides:       bundled(select2) = 4.0.13
#Provides:       bundled(xregexp) = 3.2.0

# Make sure this replaces any other Django package
#Provides:       python3-django-impl
#Conflicts:      python3-django-impl

%description -n python3-django %_description

%prep
%autosetup -p1 -n %{pkgname}-%{version}

# hard-code python3 in django-admin
pushd django
for file in conf/project_template/manage.py-tpl ; do
    sed -i "s/\/env python/\/python3/" $file ;
done
popd

# Use non optimised psycopg for tests
sed -i 's/psycopg\[binary\]>=3\.1\.8/psycopg>=3.1.8/' tests/requirements/postgres.txt

# Remove unnecessary test BRs
sed -i '/^pywatchman\b/d' tests/requirements/py3.txt
sed -i '/^tzdata$/d' tests/requirements/py3.txt

# Remove deps on code checkers/linters
sed -i '/^black\b/d' tests/requirements/py3.txt
sed -i '/^black\b/d' docs/requirements.txt
sed -i '/^blacken-docs\b/d' docs/requirements.txt

%generate_buildrequires
%pyproject_buildrequires -r tests/requirements/{py3,mysql}.txt docs/requirements.txt

%build
%pyproject_wheel


%install
%pyproject_install
%pyproject_save_files django


# build documentation
(cd docs && mkdir djangohtml && mkdir -p _build/{doctrees,html} && make html)
cp -ar docs ..

# install man pages (for the main executable only)
mkdir -p %{buildroot}%{_mandir}/man1/
cp -p docs/man/* %{buildroot}%{_mandir}/man1/

# install bash completion script
bashcompdir=$(pkg-config --variable=completionsdir bash-completion)
mkdir -p %{buildroot}$bashcompdir
install -m 0644 -p extras/django_bash_completion \
  %{buildroot}$bashcompdir/django-admin.py

for file in django-admin django-admin-3 django-admin-%{python3_version} python3-django-admin manage.py ; do
   ln -s django-admin.py %{buildroot}$bashcompdir/$file
done

# Add backward compatible links to %%{_bindir}
ln -s ./django-admin %{buildroot}%{_bindir}/django-admin-3
ln -s ./django-admin %{buildroot}%{_bindir}/django-admin-%{python3_version}
ln -s ./django-admin %{buildroot}%{_bindir}/python3-django-admin

# remove .po files
find %{buildroot} -name "*.po" | xargs rm -f
sed -i '/.po$/d' %{pyproject_files}

%check
# many contrib modules assume a configured app, "Requested setting INSTALLED_APPS..."
# the rest needs optional dependencies
%{pyproject_check_import \
    -e 'django.contrib.*' \
    -e 'django.core.serializers.pyyaml' \
    -e 'django.db.backends.mysql*' \
    -e 'django.db.backends.oracle*' \
    -e 'django.db.backends.postgresql*'}

cd %{_builddir}/%{pkgname}-%{version}
export PYTHONPATH=$(pwd)
cd tests

# disable two tests due to regression in 3.12b4:
# https://github.com/python/cpython/issues/106669
%{python3} runtests.py --settings=test_sqlite --verbosity=2 --parallel 1 \
%if v"%{python3_version}" >= v"3.12"
  -k "not test_safe_mime_multipart and not test_unicode_address_header"
%endif
#%%{python3} runtests.py --settings=test_sqlite --verbosity=2 --parallel 1

%files -n python3-django-bash-completion
%{_datadir}/bash-completion/*

%files -n python3-django-doc
%doc AUTHORS README.rst
%doc docs/_build/html/*

%files -n python3-django -f %{pyproject_files}
%license LICENSE
%{_bindir}/django-admin
%{_bindir}/django-admin-3
%{_bindir}/django-admin-%{python3_version}
%{_bindir}/python3-django-admin
%{_mandir}/man1/django-admin.1*


%changelog
* Fri Nov 01 2024 mgb01105731 <mgb01105731@alibaba-inc.com> - 4.2.14-1
- update to 4.2.14
- fix CVE-2024-39329

* Fri Aug 02 2024 yangxinyu <yangxinyu@nfschina.com> - 4.2.11-2
- fix cve-2024-38875

## START: Generated by rpmautospec
* Thu May 09 2024 mgb01105731 <mgb01105731@alibaba-inc.com> - 4.2.11-1
- update to 4.2.11

* Wed Mar 27 2024 Zhao Hang <wb-zh951434@alibaba-inc.com> - 4.2.7-2
- Rebuild with python3.11

* Mon Nov 06 2023 Funda Wang <fundawang@yeah.net> - 4.2.7-1
- New version 4.2.7

* Thu Oct 05 2023 Funda Wang <fundawang@yeah.net> - 4.2.6-1
- New version 4.2.6

* Thu May 25 2023 Funda Wang <fundawang@yeah.net> - 4.1.9-1
- New version 4.1.9

* Sat May 06 2023 Funda Wang <fundawang@yeah.net> - 4.1.7-1
- Import package for anolis 23
